package com.good.domain;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;

/**
 * Deserialized data from request body. Data will be used for creation of certificates in {@link com.good.service.CertificateServerService}.
 */
public class GDP12CertificateRequest {

    /**
     * Will be used as password in created PKCS12 keystore.
     */
	private String authToken;
	/**
	 * User email addr or some other identifier.
	 * Subject for the certificate is created by the issuer.
	 */
	private String user;
	/**
	 * request ID is used in response for mapping it with request
	 */
	private String reqId;
	/**
	 * Type of request. Currently only "initialCert" is supported
	 */
	private RequestTypeEnum mType;

	public String getUser() {
		return user;
	}

	public void setUser(final String user) {
		this.user = user;
	}

	public String getReqId() {
		return reqId;
	}

	public void setReqId(final String reqId) {
		this.reqId = reqId;
	}

	public String getAuthToken() {
		return authToken;
	}

	public void setAuthToken(final String authToken) {
		this.authToken = authToken;
	}

	public RequestTypeEnum getmType() {
		return this.mType;
	}

	public void setmType(final RequestTypeEnum requestType) {
		this.mType = requestType;
	}

	public enum RequestTypeEnum {

		INITIAL_CERT("initialCert"), RENEW_CERT("renewCert");
		private final String val;

		RequestTypeEnum(String val) {
			this.val = val;
		}

        @JsonValue
		public String getValue() {
			return this.val;
		}

        @JsonCreator
		public static RequestTypeEnum getByValue(String value) {
			switch (value) {
			case "initialCert":
				return INITIAL_CERT;
			case "renewCert":
				return RENEW_CERT;
			default:
				return null;
			}
		}
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result
				+ ((authToken == null) ? 0 : authToken.hashCode());
		result = prime * result + ((reqId == null) ? 0 : reqId.hashCode());
		result = prime * result
				+ ((mType == null) ? 0 : mType.hashCode());
		result = prime * result + ((user == null) ? 0 : user.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		GDP12CertificateRequest other = (GDP12CertificateRequest) obj;
		if (authToken == null) {
			if (other.authToken != null)
				return false;
		} else if (!authToken.equals(other.authToken))
			return false;
		if (reqId == null) {
			if (other.reqId != null)
				return false;
		} else if (!reqId.equals(other.reqId))
			return false;
		if (mType != other.mType)
			return false;
		if (user == null) {
			if (other.user != null)
				return false;
		} else if (!user.equals(other.user))
			return false;
		return true;
	}

    @Override
    public String toString() {
        return "GDP12CertificateRequest{" +
                "authToken='" + authToken + '\'' +
                ", user='" + user + '\'' +
                ", reqId='" + reqId + '\'' +
                ", mType=" + mType +
                '}';
    }
}
